diff --git a/src/java/org/apache/lucene/store/FSDirectory.java b/src/java/org/apache/lucene/store/FSDirectory.java
index b5678c0a296..51ec6ed777f 100644
--- a/src/java/org/apache/lucene/store/FSDirectory.java
+++ b/src/java/org/apache/lucene/store/FSDirectory.java
@@ -49,11 +49,11 @@ public class FSDirectory extends Directory {
Boolean.getBoolean("disableLuceneLocks") || Constants.JAVA_1_1;
/**
* Directory specified by org.apache.lucene.lockdir
* or java.io.tmpdir
system property
*/
public static final String LOCK_DIR =
- System.getProperty("org.apache.lucene.lockdir",
+ System.getProperty("org.apache.lucene.lockDir",
System.getProperty("java.io.tmpdir"));
/** The default class which implements filesystem-based directories. */
@@ -49,11 +49,11 @@ public class FSDirectory extends Directory {
Boolean.getBoolean("disableLuceneLocks") || Constants.JAVA_1_1;
/**
- * Directory specified by org.apache.lucene.lockdir
+ * Directory specified by org.apache.lucene.lockDir
* or java.io.tmpdir
system property